import Logger from "../../utils/logger.js";
import { getAllComponents } from "../components/components.js";
import { getPreset } from "./presets.js";
export const getComponentPresets = (componentName, config) => {
    Logger.log(`Trying to get all '${componentName}' presets.`);
    return getAllComponents(config).then(async (res) => {
        const componentPresets = res.filter((component) => component.name === componentName);
        if (componentPresets.length > 0) {
            if (componentPresets[0].all_presets.length === 0) {
                Logger.warning(`There is no presets for: '${componentName}' component`);
                return false;
            }
            return Promise.all(componentPresets[0].all_presets.map((preset) => getPreset({ presetId: preset.id }, config).catch((err) => Logger.error(err))));
        }
        Logger.warning(`There is no '${componentName}' component`);
        return false;
    });
};
