import { rollup } from "rollup";
export async function build({ inputOptions, outputOptionsList }) {
    let bundle;
    let buildFailed = false;
    try {
        bundle = await rollup(inputOptions);
        await generateOutputs({ bundle, outputOptionsList });
        return [];
    }
    catch (error) {
        buildFailed = true;
        console.error(error);
    }
    if (bundle) {
        await bundle.close();
    }
    process.exit(buildFailed ? 1 : 0);
}
async function generateOutputs({ bundle, outputOptionsList }) {
    for (const outputOptions of outputOptionsList) {
        const { output } = await bundle.write(outputOptions);
        for (const chunkOrAsset of output) {
            if (chunkOrAsset.type === "asset") {
                if (process.env["DEBUG"]) {
                    console.log("Asset", chunkOrAsset);
                }
            }
            else {
                if (process.env["DEBUG"]) {
                    console.log("Chunk", chunkOrAsset.modules);
                }
            }
        }
    }
}
